SampleMetadata

Enum SampleMetadata 

pub enum SampleMetadata {
    UnknownAccuracy,
    NoMeasurementError,
    SymmetricalError {
        deviation: u8,
        bias: i8,
        scaling: i8,
    },
    ChannelTemporarilyUnavailable,
    ChannelDisabled,
}
Metadata associated with a Sample.

Includes the measurement accuracy if available.

Variants



UnknownAccuracy

Unknown accuracy.



NoMeasurementError

No observational/measurement error (e.g., boolean values from a push button).



SymmetricalError

Measurement error symmetrical around the bias.

The unit of measurement is provided by the ReadingChannel associated with the Sample. The scaling value is used for both deviation and bias. The accuracy error is thus given by the following formulas:

+(bias+deviation)·10scaling/-(bias-deviation)·10scaling

Examples

The DS18B20 temperature sensor accuracy error is +0.05/-0.45 at 20 °C (see Figure 1 of its datasheet). SampleMetadata would thus be the following:

SampleMetadata::SymmetricalError {
    deviation: 25,
    bias: -20,
    scaling: -2,
}

Fields

deviation: u8

Deviation around the bias value.

bias: i8

Bias (mean accuracy error).

scaling: i8

Scaling of deviation and bias.



ChannelTemporarilyUnavailable

Indicates that the channel is temporarily unavailable. This may happen when parts of a sensor are not ready yet, but data is already available for other channels.



ChannelDisabled

The channel is disabled by configuration.